@@ -345,6 +345,7 @@ def gbq(
     Service name defaults to "pygbq" and endpoint is function name, could be rewritten.
     https://cloud.google.com/appengine/docs/admin-api/getting-started
     Bool parameter start_now (defaults to True) indicates whether to create a table now or wait until cron job does it
+    RETURNS a dict with data in it
     """
 
     # Test correctness of table_id and set dataset and table_name
@@ -520,7 +521,7 @@ def gbq(
                 # should add to result if fails
         else:  # shouldn't happen because I check return type before
             raise MyError("Return either list; df; (list, schema); (df, schema)")
-        return {"status": "success", "data_len": len(data), **kwargs}
+        return {"status": "success", "data_len": len(data), "data": data, **kwargs}
 
     return inner
 
